@@ -15,7 +15,6 @@
 #
 from datetime import timedelta
 import requests
-import six
 
 from gnocchiclient import auth as gauth
 from gnocchiclient import client as gclient
@@ -36,7 +35,6 @@ from cloudkitty import dataframe
 from cloudkitty import utils as ck_utils
 from cloudkitty.utils import tz as tzutils
 
-
 LOG = logging.getLogger(__name__)
 
 COLLECTOR_GNOCCHI_OPTS = 'collector_gnocchi'
@@ -93,7 +91,7 @@ for agg in list(BASIC_AGGREGATION_METHODS):
     BASIC_AGGREGATION_METHODS.add("rate:%s" % agg)
 
 EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY = set(
-    (str(i) + 'pct' for i in six.moves.range(1, 100)))
+    (str(i) + 'pct' for i in range(1, 100)))
 
 for agg in list(EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY):
     EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY.add("rate:%s" % agg)
@@ -115,6 +113,22 @@ GNOCCHI_EXTRA_SCHEMA = {
         Required('re_aggregation_method', default='max'):
             In(BASIC_AGGREGATION_METHODS),
         Required('force_granularity', default=3600): All(int, Range(min=0)),
+        Required('use_all_resource_revisions', default=True): All(bool),
+        # Provide means for operators to customize the aggregation query
+        # executed against Gnocchi. By default we use the following:
+        #
+        # '(aggregate RE_AGGREGATION_METHOD
+        #   (metric METRIC_NAME AGGREGATION_METHOD))'
+        #
+        # Therefore, this option enables operators to take full advantage of
+        # operations available in Gnocchi, such as any arithmetic operations,
+        # logical operations and many others.
+        #
+        # When using a custom aggregation query, you can keep the placeholders
+        # 'RE_AGGREGATION_METHOD', 'AGGREGATION_METHOD', and 'METRIC_NAME':
+        # they will be replaced at runtime by values from the metric
+        # configuration.
+        Required('custom_query', default=''): All(str),
     },
 }
 
@@ -320,7 +334,7 @@ class GnocchiCollector(collector.BaseCollector):
             # FIXME(peschk_l): gnocchiclient seems to be raising a BadRequest
             # when it should be raising MetricNotFound
             if isinstance(e, gexceptions.BadRequest):
-                if 'Metrics not found' not in six.text_type(e):
+                if 'Metrics not found' not in e.message["cause"]:
                     raise
             LOG.warning('[{scope}] Skipping this metric for the '
                         'current cycle.'.format(scope=project_id, err=e))
@@ -370,9 +384,32 @@ class GnocchiCollector(collector.BaseCollector):
     def build_operation_command(self, metric_name):
         extra_args = self.conf[metric_name]['extra_args']
 
-        re_aggregation_method = extra_args['re_aggregation_method']
+        op = self.generate_aggregation_operation(extra_args, metric_name)
+
+        LOG.debug("Aggregation operation [%s] used to retrieve metric [%s].",
+                  op, metric_name)
+        return op
+
+    @staticmethod
+    def generate_aggregation_operation(extra_args, metric_name):
+        aggregation_method = extra_args['aggregation_method']
+        re_aggregation_method = aggregation_method
+
+        if 're_aggregation_method' in extra_args:
+            re_aggregation_method = extra_args['re_aggregation_method']
+
         op = ["aggregate", re_aggregation_method,
-              ["metric", metric_name, extra_args['aggregation_method']]]
+              ["metric", metric_name, aggregation_method]]
+
+        custom_gnocchi_query = extra_args.get('custom_query')
+        if custom_gnocchi_query:
+            LOG.debug("Using custom Gnocchi query [%s] with metric [%s].",
+                      custom_gnocchi_query, metric_name)
+            op = custom_gnocchi_query.replace(
+                'RE_AGGREGATION_METHOD', re_aggregation_method).replace(
+                'AGGREGATION_METHOD', aggregation_method).replace(
+                'METRIC_NAME', metric_name)
+
         return op
 
     def _format_data(self, metconf, data, resources_info=None):
@@ -397,7 +434,9 @@ class GnocchiCollector(collector.BaseCollector):
         qty = data['measures']['measures']['aggregated'][0][2]
         converted_qty = ck_utils.convert_unit(
             qty, metconf['factor'], metconf['offset'])
-        mutated_qty = ck_utils.mutate(converted_qty, metconf['mutate'])
+        mutate_map = metconf.get('mutate_map')
+        mutated_qty = ck_utils.mutate(converted_qty, metconf['mutate'],
+                                      mutate_map=mutate_map)
         return metadata, groupby, mutated_qty
 
     def fetch_all(self, metric_name, start, end,
@@ -413,6 +452,9 @@ class GnocchiCollector(collector.BaseCollector):
             q_filter=q_filter,
         )
 
+        data = GnocchiCollector.filter_unecessary_measurements(
+            data, met, metric_name)
+
         resources_info = None
         if met['metadata']:
             resources_info = self._fetch_resources(
@@ -422,9 +464,13 @@ class GnocchiCollector(collector.BaseCollector):
                 project_id=project_id,
                 q_filter=q_filter
             )
+
         formated_resources = list()
         for d in data:
             # Only if aggregates have been found
+            LOG.debug("Processing entry [%s] for [%s] in timestamp ["
+                      "start=%s, end=%s] and project id [%s]", d,
+                      metric_name, start, end, project_id)
             if d['measures']['measures']['aggregated']:
                 try:
                     metadata, groupby, qty = self._format_data(
@@ -444,3 +490,40 @@ class GnocchiCollector(collector.BaseCollector):
                     metadata,
                 ))
         return formated_resources
+
+    @staticmethod
+    def filter_unecessary_measurements(data, met, metric_name):
+        """Filter unecessary measurements if not 'use_all_resource_revisions'
+
+        The option 'use_all_resource_revisions' is useful when using Gnocchi
+        with the patch introduced in
+        https://github.com/gnocchixyz/gnocchi/pull/1059.
+
+        That patch can cause queries to return more than one entry per
+        granularity (timespan), according to the revisions a resource has.
+        This can be problematic when using the 'mutate' option of Cloudkitty.
+        Therefore, this option ('use_all_resource_revisions') allows operators
+        to discard all datapoints returned from Gnocchi, but the last one in
+        the granularity queried by CloudKitty. The default behavior is
+        maintained, which means, CloudKitty always use all of the data
+        points returned.
+        """
+
+        use_all_resource_revisions = \
+            met['extra_args']['use_all_resource_revisions']
+        LOG.debug("Configuration use_all_resource_revisions set to [%s] for "
+                  "%s", use_all_resource_revisions, metric_name)
+
+        if data and not use_all_resource_revisions:
+            data.sort(
+                key=lambda x: (x["group"]["id"], x["group"]["revision_start"]),
+                reverse=False)
+
+            # We just care about the oldest entry per resource ID in the
+            # given time slice (configured granularity in Cloudkitty).
+            single_entries_per_id = {d["group"]["id"]: d for d in
+                                     data}.values()
+            LOG.debug("Replaced list of data points [%s] with [%s] for "
+                      "metric [%s]", data, single_entries_per_id, metric_name)
+            data = single_entries_per_id
+        return data
